| first_order_kinetics | R Documentation |
This function calculates the rate constant, half-life, and provides a summary of the first-order dissipation kinetics of pesticides, including the intercept, R^2 value, and statistical measures of the fitted model.
first_order_kinetics(t, c)
t |
Numeric vector, time points. |
c |
Numeric vector, concentrations corresponding to each time point. |
The function performs a logarithmic transformation on the concentration values to fit a linear model which corresponds to the first-order kinetics equation. A negative of the slope of this model gives the rate constant, and the half-life is calculated using the natural logarithm of 2 divided by the rate constant.
A list containing the following components:
rate constant |
The calculated rate constant for the first-order kinetics. |
half life |
The calculated half-life based on the rate constant. |
summary |
A summary object providing statistical measures of the fitted model, including the intercept, R^2 value, among others. |
lm, for details on the linear models used within.
t <- c(0, 5, 10, 15, 20, 25)
c <- c(100, 80, 60, 40, 20, 10)
first_order_kinetics(t, c)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.