| plot_first_order_kinetics | R Documentation |
This function plots the actual and predicted concentrations based on first-order kinetics.
plot_first_order_kinetics(t, c, kinetic_model)
t |
Numeric vector of time points. |
c |
Numeric vector of concentrations corresponding to each time point. |
kinetic_model |
Model object, result of lm function fitting log(c) ~ t. |
This function generates a plot of the actual vs. predicted concentrations based on the provided kinetic model and data points. The plot is rendered directly to the active plotting device.
t <- c(0, 5, 10, 15, 20, 25)
c <- c(100, 80, 60, 40, 20, 10)
model <- lm(log(c) ~ t)
plot_first_order_kinetics(t, c, model)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.